@@ -1,37 +1,34 @@
-//============================================================================
-//
-// Terence Welsh Screensaver - Euphoria
-// http://www.reallyslick.com/
-//
-// Ported to KDE by Karl Robillard
-//
 /*
- * Copyright (C) 2002  Terence M. Welsh
+ *  Terence Welsh Screensaver - Euphoria
+ *  http://www.reallyslick.com/
  *
- * Euphoria is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation.
+ *  Ported to KDE by Karl Robillard
+ *  Copyright (C) 2002  Terence M. Welsh
  *
- * Euphoria is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU General Public License as
+ *  published by the Free Software Foundation; either version 2 of 
+ *  the License, or (at your option) any later version.
+ *   
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *   
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-//============================================================================
-
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
 #include <time.h>
 #include <qtimer.h>
+
 #include "Euphoria.h"
 #include "Euphoria.moc"
 #include "EuphoriaTexture.h"
+#include <GL/glu.h>
 
 
 #define NUMCONSTS 9
@@ -74,23 +71,23 @@ public:
     float & operator [] (int i) {return v[i];}
     const float & operator [] (int i) const {return v[i];}
     rsVec & operator = (const rsVec &vec)
-        {v[0]=vec[0];v[1]=vec[1];v[2]=vec[2];return *this;};
+        {v[0]=vec[0];v[1]=vec[1];v[2]=vec[2];return *this;}
     rsVec operator + (const rsVec &vec)
-        {return(rsVec(v[0]+vec[0], v[1]+vec[1], v[2]+vec[2]));};
+        {return(rsVec(v[0]+vec[0], v[1]+vec[1], v[2]+vec[2]));}
     rsVec operator - (const rsVec &vec)
-        {return(rsVec(v[0]-vec[0], v[1]-vec[1], v[2]-vec[2]));};
+        {return(rsVec(v[0]-vec[0], v[1]-vec[1], v[2]-vec[2]));}
     rsVec operator * (const float &mul)
-        {return(rsVec(v[0]*mul, v[1]*mul, v[2]*mul));};
+        {return(rsVec(v[0]*mul, v[1]*mul, v[2]*mul));}
     rsVec operator / (const float &div)
-        {float rec = 1.0f/div; return(rsVec(v[0]*rec, v[1]*rec, v[2]*rec));};
+        {float rec = 1.0f/div; return(rsVec(v[0]*rec, v[1]*rec, v[2]*rec));}
     rsVec & operator += (const rsVec &vec)
-        {v[0]+=vec[0];v[1]+=vec[1];v[2]+=vec[2];return *this;};
+        {v[0]+=vec[0];v[1]+=vec[1];v[2]+=vec[2];return *this;}
     rsVec & operator -= (const rsVec &vec)
-        {v[0]-=vec[0];v[1]-=vec[1];v[2]-=vec[2];return *this;};
+        {v[0]-=vec[0];v[1]-=vec[1];v[2]-=vec[2];return *this;}
     rsVec & operator *= (const rsVec &vec)
-        {v[0]*=vec[0];v[1]*=vec[1];v[2]*=vec[2];return *this;};
+        {v[0]*=vec[0];v[1]*=vec[1];v[2]*=vec[2];return *this;}
     rsVec & operator *= (const float &mul)
-        {v[0]*=mul;v[1]*=mul;v[2]*=mul;return *this;};
+        {v[0]*=mul;v[1]*=mul;v[2]*=mul;return *this;}
 };
 
 
@@ -457,8 +454,8 @@ void wisp::drawAsBackground()
 //----------------------------------------------------------------------------
 
 
-EuphoriaWidget::EuphoriaWidget( QWidget* parent, const char* name )
-              : QGLWidget(parent, name), texName(0), _wisps(0), _backwisps(0),
+EuphoriaWidget::EuphoriaWidget( QWidget* parent )
+              : QGLWidget(parent), texName(0), _wisps(0), _backwisps(0),
 	      feedbackmap(0), feedbacktex(0)
 {
     setDefaults( Regular );
@@ -716,10 +713,10 @@ void EuphoriaWidget::updateParameters()
 
 	if(dFeedback)
     {
-		feedbacktexsize = int(pow(2, dFeedbacksize));
+		feedbacktexsize = int(pow(2.0, dFeedbacksize));
 		while(feedbacktexsize > viewport[2] || feedbacktexsize > viewport[3]){
 			dFeedbacksize -= 1;
-			feedbacktexsize = int(pow(2, dFeedbacksize));
+			feedbacktexsize = int(pow(2.0, dFeedbacksize));
 		}
 
 		// feedback texture setup
@@ -894,21 +891,31 @@ void EuphoriaWidget::setDefaults(int which)
 
 
 // libkscreensaver interface
-extern "C"
+class KEuphoriaSaverInterface : public KScreenSaverInterface
 {
-    KDE_EXPORT const char* kss_applicationName = "keuphoria.kss";
-    KDE_EXPORT const char* kss_description = I18N_NOOP( "Euphoria" );
-    KDE_EXPORT const char* kss_version = "1.0";
 
-    KDE_EXPORT KScreenSaver* kss_create( WId id )
+
+public:
+    virtual KAboutData* aboutData() {
+        return new KAboutData( "keuphoria.kss", 0, ki18n( "Euphoria" ), "1.0", ki18n( "Euphoria" ) );
+    }
+
+
+    virtual KScreenSaver* create( WId id )
     {
         return new KEuphoriaScreenSaver( id );
     }
 
-    KDE_EXPORT QDialog* kss_setup()
+    virtual QDialog* setup()
     {
         return new KEuphoriaSetup;
     }
+};
+
+int main( int argc, char *argv[] )
+{
+    KEuphoriaSaverInterface kss;
+    return kScreenSaverMain( argc, argv, kss );
 }
 
 
@@ -944,10 +951,9 @@ static int filterRandom( int n )
 
 void KEuphoriaScreenSaver::readSettings()
 {
-    KConfig* config = KGlobal::config();
-    config->setGroup("Settings");
+    KConfigGroup config(KGlobal::config(), "Settings");
 
-    _mode = config->readNumEntry( "Mode", EuphoriaWidget::Regular );
+    _mode = config.readEntry( "Mode", (int)EuphoriaWidget::Regular );
     _effect->setDefaults( filterRandom(_mode) );
 }
 
@@ -988,13 +994,18 @@ static const char* defaultText[] =
 };
 
 
-KEuphoriaSetup::KEuphoriaSetup( QWidget* parent, const char* name )
-        : KDialogBase( parent, name, true, i18n("Setup Euphoria Screen Saver"),
-          Ok|Cancel|Help, Ok, true )
+KEuphoriaSetup::KEuphoriaSetup( QWidget* parent )
+        : KDialog( parent)
 {
+    setCaption(i18n("Setup Euphoria Screen Saver"));
+	setButtons(Ok|Cancel|Help);
+	setDefaultButton(Ok);
+	setModal(true);
+	showButtonSeparator(true);
     setButtonText( Help, i18n( "A&bout" ) );
 
-    QWidget *main = makeMainWidget();
+    QWidget *main = new QWidget(this);
+	setMainWidget(main);
 
     QHBoxLayout* top    = new QHBoxLayout(main, 0, spacingHint());
     QVBoxLayout* leftCol = new QVBoxLayout;
@@ -1015,7 +1026,7 @@ KEuphoriaSetup::KEuphoriaSetup( QWidget* parent, const char* name )
     QWidget* preview;
     preview = new QWidget( main );
     preview->setFixedSize( 220, 170 );
-    preview->setBackgroundColor( black );
+    preview->setBackgroundColor( Qt::black );
     preview->show();    // otherwise saver does not get correct size
     _saver = new KEuphoriaScreenSaver( preview->winId() );
     top->addWidget(preview);
@@ -1023,6 +1034,8 @@ KEuphoriaSetup::KEuphoriaSetup( QWidget* parent, const char* name )
     // Now that we have _saver...
     modeW->setCurrentItem( _saver->mode() );    // set before we connect
     connect( modeW, SIGNAL(activated(int)), _saver, SLOT(setMode(int)) );
+	connect(this,SIGNAL(okClicked()),SLOT(slotOk()));
+	connect(this,SIGNAL(helpClicked()),SLOT(slotHelp()));
 
     setMinimumSize( sizeHint() );
 }
@@ -1038,7 +1051,7 @@ void KEuphoriaSetup::slotHelp()
 {
     KMessageBox::about(this,
         i18n("<h3>Euphoria 1.0</h3>\n<p>Copyright (c) 2002 Terence M. Welsh<br>\n<a href=\"http://www.reallyslick.com/\">http://www.reallyslick.com/</a></p>\n\n<p>Ported to KDE by Karl Robillard</p>"),
-        QString::null, KMessageBox::AllowLink);
+        QString(), KMessageBox::AllowLink);
 }
 
 
@@ -1047,14 +1060,13 @@ void KEuphoriaSetup::slotHelp()
 */
 void KEuphoriaSetup::slotOk()
 {
-    KConfig* config = KGlobal::config();
-    config->setGroup("Settings");
+    KConfigGroup config( KGlobal::config(), "Settings");
 
     QString val;
     val.setNum( modeW->currentItem() );
-    config->writeEntry("Mode", val );
+    config.writeEntry("Mode", val );
 
-    config->sync();
+    config.sync();
     accept();
 }
 #endif
