@@ -7,7 +7,7 @@
 //
 // Developed by Georg Drenkhahn, georg-d@users.sourceforge.net
 //
-// $Id: pendulum.cpp 435075 2005-07-16 08:53:15Z mueller $
+// $Id: pendulum.cpp 787229 2008-03-18 20:26:20Z winterz $
 //
 /*
  * Copyright (C) 2004 Georg Drenkhahn
@@ -21,8 +21,8 @@
  * A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
- * Place, Suite 330, Boston, MA 02110-1301 USA
+ * this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 //============================================================================
 
@@ -38,9 +38,11 @@
 #include <qcolordialog.h>
 #include <qpushbutton.h>
 #include <qtooltip.h>
+#include <QResizeEvent>
 // KDE headers
 #include <klocale.h>
 #include <kconfig.h>
+#include <kglobal.h>
 #include <kdebug.h>
 #include <kmessagebox.h>
 
@@ -51,28 +53,37 @@
 
 #define KPENDULUM_VERSION "1.1"
 
+const unsigned int KPendulumSaver::persChangeIntervalLimitLower;
+const unsigned int KPendulumSaver::persChangeIntervalLimitUpper;
+const unsigned int KPendulumSaver::persChangeIntervalDefault;
+
 // libkscreensaver interface
-extern "C"
+class KPendulumSaverInterface : public KScreenSaverInterface
 {
-   /// application name for libkscreensaver interface
-   KDE_EXPORT const char *kss_applicationName = "kpendulum.kss";
-   /// application description for libkscreensaver interface
-   KDE_EXPORT const char *kss_description = I18N_NOOP("Simulation of\
- a two-part pendulum");
-   /// application version for libkscreensaver interface
-   KDE_EXPORT const char *kss_version = KPENDULUM_VERSION;
+   /// aboutdata instance for libkscreensaver interface
+public:
+    virtual KAboutData* aboutData() {
+        return new KAboutData( "kpendulum.kss", 0, ki18n("Simulation of a two-part pendulum"), KPENDULUM_VERSION, ki18n("Simulation of a two-part pendulum") );
+    }
+
 
    /// function to create screen saver object
-   KDE_EXPORT KScreenSaver* kss_create(WId id)
+   virtual KScreenSaver* create(WId id)
    {
       return new KPendulumSaver(id);
    }
 
    /// function to create setup dialog for screen saver
-   KDE_EXPORT QDialog* kss_setup()
+   virtual QDialog* setup()
    {
       return new KPendulumSetup();
    }
+};
+
+int main( int argc, char *argv[] )
+{
+    KPendulumSaverInterface kss;
+    return kScreenSaverMain( argc, argv, kss );
 }
 
 //-----------------------------------------------------------------------------
@@ -131,8 +142,8 @@ std::valarray<double> PendulumOdeSolver::f(
 // Rotation: screen saver widget
 //-----------------------------------------------------------------------------
 
-PendulumGLWidget::PendulumGLWidget(QWidget* parent, const char* name)
-   : QGLWidget(parent, name),
+PendulumGLWidget::PendulumGLWidget(QWidget* parent)
+   : QGLWidget(parent),
      eyeR(30),                  // eye coordinates (polar)
      eyeTheta(M_PI*0.45),
      eyePhi(0),
@@ -209,7 +220,7 @@ void PendulumGLWidget::setM2Color(const QColor& c)
 
 void PendulumGLWidget::initializeGL(void)
 {
-   qglClearColor(QColor(black)); // set color to clear the background
+   qglClearColor(QColor(Qt::black)); // set color to clear the background
 
    glClearDepth(1);             // depth buffer setup
    glEnable(GL_DEPTH_TEST);     // depth testing
@@ -227,14 +238,14 @@ void PendulumGLWidget::initializeGL(void)
 
    glMatrixMode(GL_MODELVIEW);           // select modelview matrix
    glLoadIdentity();
-   // set positon of light0
+   // set position of light0
    GLfloat lightPos[4]=
       {lightR * sin(lightTheta) * sin(lightPhi),
        lightR * sin(lightTheta) * cos(lightPhi),
        lightR * cos(lightTheta),
        0};
    glLightfv(GL_LIGHT0, GL_POSITION, lightPos);
-   // set positon of light1
+   // set position of light1
    lightPos[0] = lightR * sin(lightTheta) * sin(lightPhi+M_PI);
    lightPos[1] = lightR * sin(lightTheta) * cos(lightPhi+M_PI);
    glLightfv(GL_LIGHT1, GL_POSITION, lightPos);
@@ -367,8 +378,7 @@ KPendulumSaver::KPendulumSaver(WId id) :
    m_E(EDefault),
    m_persChangeInterval(persChangeIntervalDefault)
 {
-   setEraseColor(black);
-   erase();                     // erase area
+   setEraseColor(Qt::black);
    glArea = new PendulumGLWidget(this); // create gl widget
    glArea->setEyePhi(eyePhiDefault);
 
@@ -380,7 +390,7 @@ KPendulumSaver::KPendulumSaver(WId id) :
 
    // set up and start cyclic timer
    timer = new QTimer(this);
-   timer->start(deltaT, TRUE);
+   timer->start(deltaT, true);
    connect(timer, SIGNAL(timeout()), this, SLOT(doTimeStep()));
 }
 
@@ -394,36 +404,35 @@ KPendulumSaver::~KPendulumSaver()
 void KPendulumSaver::readSettings()
 {
    // read configuration settings from config file
-   KConfig *config = KGlobal::config();
-   config->setGroup("Settings");
+   KConfigGroup config(KGlobal::config(), "Settings");
 
    // internal saver parameters are set to stored values or left at their
    // default values if stored values are out of range
    setMassRatio(
-      config->readDoubleNumEntry(
+      config.readEntry(
          "mass ratio",
          KPendulumSaver::massRatioDefault));
    setLengthRatio(
-      config->readDoubleNumEntry(
+      config.readEntry(
          "length ratio",
          KPendulumSaver::lengthRatioDefault));
    setG(
-      config->readDoubleNumEntry(
+      config.readEntry(
          "g",
          KPendulumSaver::gDefault));
    setE(
-      config->readDoubleNumEntry(
+      config.readEntry(
          "E",
          KPendulumSaver::EDefault));
    setPersChangeInterval(
-      config->readUnsignedNumEntry(
+      config.readEntry(
          "perspective change interval",
-         KPendulumSaver::persChangeIntervalDefault));
+         (uint)KPendulumSaver::persChangeIntervalDefault));
 
    // set the colours
-   setBarColor(config->readColorEntry("bar color", &barColorDefault));
-   setM1Color( config->readColorEntry("m1 color",  &m1ColorDefault));
-   setM2Color( config->readColorEntry("m2 color",  &m2ColorDefault));
+   setBarColor(config.readEntry("bar color", barColorDefault));
+   setM1Color( config.readEntry("m1 color",  m1ColorDefault));
+   setM2Color( config.readEntry("m2 color",  m2ColorDefault));
 }
 
 void KPendulumSaver::initData()
@@ -503,7 +512,7 @@ const QColor KPendulumSaver::m2ColorDefault( 85, 170, 127);
 
 void KPendulumSaver::setMassRatio(const double& massRatio)
 {
-   // range check is not neccessary in normal operation because validators check
+   // range check is not necessary in normal operation because validators check
    // the values at input.  But the validators do not check for corrupted
    // settings read from disk.
    if (massRatio >= massRatioLimitLower
@@ -657,7 +666,7 @@ void KPendulumSaver::doTimeStep()
    }
 
    glArea->updateGL();          // repaint scenery
-   timer->start(deltaT, TRUE);  // restart timer
+   timer->start(deltaT, true);  // restart timer
 }
 
 // public slot of KPendulumSaver, forward resize event to public slot of glArea
@@ -671,14 +680,14 @@ void KPendulumSaver::resizeGlArea(QResizeEvent* e)
 // KPendulumSetup: dialog to setup screen saver parameters
 //-----------------------------------------------------------------------------
 
-KPendulumSetup::KPendulumSetup(QWidget* parent, const char* name)
-   : KPendulumSetupUi(parent, name),
+KPendulumSetup::KPendulumSetup(QWidget* parent)
+   : KPendulumSetupUi(parent),
      // create saver and give it the WinID of the preview area
      saver(new KPendulumSaver(preview->winId()))
 {
    // the dialog should block, no other control center input should be possible
    // until the dialog is closed
-   setModal(TRUE);
+   setModal(true);
 
    // create input validators
    mEdit->setValidator(new QDoubleValidator(
@@ -703,34 +712,34 @@ KPendulumSetup::KPendulumSetup(QWidget* parent, const char* name)
    persSpinBox->setMaxValue(KPendulumSaver::persChangeIntervalLimitUpper);
 
    // set tool tips of editable fields
-   QToolTip::add(
-      mEdit,
-      i18n("Ratio of 2nd mass to sum of both masses.\nValid values from %1 to %2.")
-      .arg(KPendulumSaver::massRatioLimitLower, 0, 'f', 2)
-      .arg(KPendulumSaver::massRatioLimitUpper, 0, 'f', 2));
-   QToolTip::add(
-      lEdit,
-      i18n("Ratio of 2nd pendulum part length to the sum of both part lengths.\nValid values from %1 to %2.")
-      .arg(KPendulumSaver::lengthRatioLimitLower, 0, 'f', 2)
-      .arg(KPendulumSaver::lengthRatioLimitUpper, 0, 'f', 2));
-   QToolTip::add(
-      gEdit,
-      i18n("Gravitational constant in arbitrary units.\nValid values from %1 to %2.")
-      .arg(KPendulumSaver::gLimitLower, 0, 'f', 2)
-      .arg(KPendulumSaver::gLimitUpper, 0, 'f', 2));
-   QToolTip::add(
-      eEdit,
-      i18n("Energy in units of the maximum potential energy of the given configuration.\nValid values from %1 to %2.")
-      .arg(KPendulumSaver::ELimitLower, 0, 'f', 2)
-      .arg(KPendulumSaver::ELimitUpper, 0, 'f', 2));
-   QToolTip::add(
-      persSpinBox,
-      i18n("Time in seconds after which a random perspective change occurs.\nValid values from %1 to %2.")
-      .arg(KPendulumSaver::persChangeIntervalLimitLower)
-      .arg(KPendulumSaver::persChangeIntervalLimitUpper));
+   mEdit->setToolTip(
+      ki18n("Ratio of 2nd mass to sum of both masses.\nValid values from %1 to %2.")
+      .subs(KPendulumSaver::massRatioLimitLower, 0, 'f', 2)
+      .subs(KPendulumSaver::massRatioLimitUpper, 0, 'f', 2)
+      .toString());
+   lEdit->setToolTip(
+      ki18n("Ratio of 2nd pendulum part length to the sum of both part lengths.\nValid values from %1 to %2.")
+      .subs(KPendulumSaver::lengthRatioLimitLower, 0, 'f', 2)
+      .subs(KPendulumSaver::lengthRatioLimitUpper, 0, 'f', 2)
+      .toString());
+   gEdit->setToolTip(
+      ki18n("Gravitational constant in arbitrary units.\nValid values from %1 to %2.")
+      .subs(KPendulumSaver::gLimitLower, 0, 'f', 2)
+      .subs(KPendulumSaver::gLimitUpper, 0, 'f', 2)
+      .toString());
+   eEdit->setToolTip(
+      ki18n("Energy in units of the maximum potential energy of the given configuration.\nValid values from %1 to %2.")
+      .subs(KPendulumSaver::ELimitLower, 0, 'f', 2)
+      .subs(KPendulumSaver::ELimitUpper, 0, 'f', 2)
+      .toString());
+   persSpinBox->setToolTip(
+      ki18n("Time in seconds after which a random perspective change occurs.\nValid values from %1 to %2.")
+      .subs(KPendulumSaver::persChangeIntervalLimitLower)
+      .subs(KPendulumSaver::persChangeIntervalLimitUpper)
+      .toString());
 
    // init preview area
-   preview->setBackgroundColor(black);
+   preview->setBackgroundColor(Qt::black);
    preview->show();    // otherwise saver does not get correct size
 
    // read settings from saver and update GUI elements with these values, saver
@@ -758,6 +767,18 @@ KPendulumSetup::KPendulumSetup(QWidget* parent, const char* name)
    // preview area.
    connect(preview, SIGNAL(resized(QResizeEvent*)),
            saver,   SLOT(resizeGlArea(QResizeEvent*)));
+
+   connect(lEdit, SIGNAL(lostFocus()), this, SLOT(lEditLostFocusSlot()));
+   connect(gEdit, SIGNAL(lostFocus()), this, SLOT(gEditLostFocusSlot()));
+   connect(eEdit, SIGNAL(lostFocus()), this, SLOT(eEditLostFocusSlot()));
+   connect(persSpinBox, SIGNAL(valueChanged(int)), this, SLOT(persChangeEnteredSlot(int)));
+   connect(mEdit, SIGNAL(lostFocus()), this, SLOT(mEditLostFocusSlot()));
+   connect(barColorButton, SIGNAL(clicked()), this, SLOT(barColorButtonClickedSlot()));
+   connect(m1ColorButton, SIGNAL(clicked()), this, SLOT(m1ColorButtonClickedSlot()));
+   connect(m2ColorButton, SIGNAL(clicked()), this, SLOT(m2ColorButtonClickedSlot()));
+   connect(OkButton, SIGNAL(clicked()), this, SLOT(okButtonClickedSlot()));
+   connect(CancelButton, SIGNAL(clicked()), this, SLOT(close()));
+   connect(AboutButton, SIGNAL(clicked()), this, SLOT(aboutButtonClickedSlot()));
 }
 
 KPendulumSetup::~KPendulumSetup()
@@ -768,20 +789,19 @@ KPendulumSetup::~KPendulumSetup()
 // Ok pressed - save settings and exit
 void KPendulumSetup::okButtonClickedSlot()
 {
-   KConfig* config = KGlobal::config();
-   config->setGroup("Settings");
+   KConfigGroup config(KGlobal::config(), "Settings");
 
-   config->writeEntry("mass ratio",   saver->massRatio());
-   config->writeEntry("length ratio", saver->lengthRatio());
-   config->writeEntry("g",            saver->g());
-   config->writeEntry("E",            saver->E());
-   config->writeEntry("perspective change interval",
+   config.writeEntry("mass ratio",   saver->massRatio());
+   config.writeEntry("length ratio", saver->lengthRatio());
+   config.writeEntry("g",            saver->g());
+   config.writeEntry("E",            saver->E());
+   config.writeEntry("perspective change interval",
                       saver->persChangeInterval());
-   config->writeEntry("bar color",    saver->barColor());
-   config->writeEntry("m1 color",     saver->m1Color());
-   config->writeEntry("m2 color",     saver->m2Color());
+   config.writeEntry("bar color",    saver->barColor());
+   config.writeEntry("m1 color",     saver->m1Color());
+   config.writeEntry("m2 color",     saver->m2Color());
 
-   config->sync();
+   config.sync();
    accept();
 }
 
@@ -854,7 +874,7 @@ void KPendulumSetup::persChangeEnteredSlot(int t)
 void KPendulumSetup::barColorButtonClickedSlot(void)
 {
    QColor color = QColorDialog::getColor(
-      saver->barColor(), this, QString("bar color dialog"));
+      saver->barColor(), this);
    if (color.isValid())
    {
       saver->setBarColor(color);
@@ -864,7 +884,7 @@ void KPendulumSetup::barColorButtonClickedSlot(void)
 void KPendulumSetup::m1ColorButtonClickedSlot(void)
 {
    QColor color = QColorDialog::getColor(
-      saver->m1Color(), this, QString("mass 1 color dialog"));
+      saver->m1Color(), this);
    if (color.isValid())
    {
       saver->setM1Color(color);
@@ -874,10 +894,11 @@ void KPendulumSetup::m1ColorButtonClickedSlot(void)
 void KPendulumSetup::m2ColorButtonClickedSlot(void)
 {
    QColor color = QColorDialog::getColor(
-      saver->m2Color(), this, QString("mass 2 color dialog"));
+      saver->m2Color(), this);
    if (color.isValid())
    {
       saver->setM2Color(color);
       m2ColorButton->setPaletteBackgroundColor(color);
    }
 }
+
