@@ -1,7 +1,7 @@
 //============================================================================
 //
 // KPendulum screen saver for KDE
-// $Id: pendulum.h 311553 2004-05-15 06:05:30Z drenkhahn $
+// $Id: pendulum.h 787229 2008-03-18 20:26:20Z winterz $
 // Copyright (C) 2004 Georg Drenkhahn
 //
 // This file is free software; you can redistribute it and/or modify it under
@@ -10,8 +10,8 @@
 //
 //============================================================================
 
-#ifndef __PENDULUM_H__
-#define __PENDULUM_H__
+#ifndef PENDULUM_H
+#define PENDULUM_H
 
 // STL headers
 #include <valarray>
@@ -29,7 +29,7 @@
 #include "rkodesolver.h"
 
 // KPendulumSetupUi
-#include "pendulumcfg.h"
+#include "ui_pendulumcfg.h"
 
 //--------------------------------------------------------------------
 
@@ -81,13 +81,12 @@ class PendulumOdeSolver : public RkOdeSolver<double>
  * Class implements QGLWidget to display the KPendulum screen saver. */
 class PendulumGLWidget : public QGLWidget
 {
-   Q_OBJECT;
+   Q_OBJECT
 
   public:
    /** @brief Constructor of KPendulum's GL widget
-    * @param parent parent widget, passed to QGLWidget's constructor
-    * @param name name of widget, passed to QGLWidget's constructor */
-   PendulumGLWidget(QWidget* parent=0, const char* name=0);
+    * @param parent parent widget, passed to QGLWidget's constructor */
+   PendulumGLWidget(QWidget* parent=0);
    /** @brief Destructor of KPendulum's GL widget */
    ~PendulumGLWidget(void);
 
@@ -133,7 +132,7 @@ class PendulumGLWidget : public QGLWidget
    virtual void paintGL();
    /** resize the gl view */
    virtual void resizeGL(int w, int h);
-   /** setup the GL enviroment */
+   /** setup the GL environment */
    virtual void initializeGL();
 
   private: // Private attributes
@@ -183,7 +182,7 @@ class PendulumGLWidget : public QGLWidget
  * This class implements KScreenSaver for the KPendulum screen saver. */
 class KPendulumSaver : public KScreenSaver
 {
-   Q_OBJECT;
+   Q_OBJECT
 
   public:
    /** @brief Constructor of the KPendulum screen saver object
@@ -326,21 +325,28 @@ class KPendulumSaver : public KScreenSaver
 
 //--------------------------------------------------------------------
 
+class KPendulumSetupUi : public QDialog, public Ui::KPendulumSetupUi
+{
+public:
+  KPendulumSetupUi( QWidget *parent ) : QDialog( parent ) {
+    setupUi( this );
+  }
+};
+
 /** @brief KPendulum screen saver setup dialog.
  *
  * This class handles the KPendulum screen saver setup dialog. */
 class KPendulumSetup : public KPendulumSetupUi
 {
-   Q_OBJECT;
+   Q_OBJECT
 
   public:
    /** @brief Constructor for the KPendulum screen saver setup dialog
     * @param parent Pointer to the parent widget, passed to KPendulumSetupUi
-    * @param name Widget name
     *
     * The dialog box is set up and the screen saver object KPendulumSetup::saver
     * is instantiated. */
-   KPendulumSetup(QWidget* parent = 0, const char* name = 0);
+   KPendulumSetup(QWidget* parent = 0);
    /** @brief Destructor of the KPendulum screen saver setup dialog
     *
     * Only KPendulumSetup::saver is deleted. */
