@@ -8,7 +8,7 @@
 //
 // Developed by Georg Drenkhahn, georg-d@users.sourceforge.net
 //
-// $Id: rotation.cpp 501235 2006-01-22 14:06:24Z mueller $
+// $Id: rotation.cpp 787229 2008-03-18 20:26:20Z winterz $
 //
 /*
  * Copyright (C) 2004 Georg Drenkhahn
@@ -22,11 +22,13 @@
  * A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
- * Place, Suite 330, Boston, MA 02110-1301 USA
+ * this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 //============================================================================
 
+#define QT_NO_COMPAT
+
 // std. C++ headers
 #include <cstdlib>
 // STL
@@ -36,8 +38,10 @@
 #include <qlineedit.h>
 #include <qvalidator.h>
 #include <qtooltip.h>
+#include <QResizeEvent>
 // KDE headers
 #include <klocale.h>
+#include <kglobal.h>
 #include <kconfig.h>
 #include <kdebug.h>
 #include <kmessagebox.h>
@@ -51,27 +55,30 @@
 #define KROTATION_VERSION "1.1"
 
 // libkscreensaver interface
-extern "C"
+class KRotationSaverInterface : public KScreenSaverInterface
 {
-   /** application name for the libkscreensaver interface */
-   KDE_EXPORT const char *kss_applicationName = "krotation.kss";
-   /** application description for the libkscreensaver interface */
-   KDE_EXPORT const char *kss_description =
-   I18N_NOOP("Simulation of a force free rotating asymmetric body");
-   /** application version for the libkscreensaver interface */
-   KDE_EXPORT const char *kss_version = KROTATION_VERSION;
+public:
+    virtual KAboutData* aboutData() {
+        return new KAboutData( "krotation.kss", 0, ki18n("Simulation of a force free rotating asymmetric body"), KROTATION_VERSION, ki18n("Simulation of a force free rotating asymmetric body") );
+    }
 
    /** function to create screen saver object */
-   KDE_EXPORT  KScreenSaver* kss_create(WId id)
+   virtual KScreenSaver* create(WId id)
    {
       return new KRotationSaver(id);
    }
 
    /** function to create setup dialog for screen saver */
-   KDE_EXPORT QDialog* kss_setup()
+   virtual QDialog* setup()
    {
       return new KRotationSetup();
    }
+};
+
+int main( int argc, char *argv[] )
+{
+    KRotationSaverInterface kss;
+    return kScreenSaverMain( argc, argv, kss );
 }
 
 //-----------------------------------------------------------------------------
@@ -137,13 +144,13 @@ std::valarray<double> EulerOdeSolver::f(
 //-----------------------------------------------------------------------------
 
 RotationGLWidget::RotationGLWidget(
-   QWidget* parent, const char* name,
+   QWidget* parent,
    const vec3<double>& _omega,
    const std::deque<vec3<double> >& e1_,
    const std::deque<vec3<double> >& e2_,
    const std::deque<vec3<double> >& e3_,
    const vec3<double>& J)
-   : QGLWidget(parent, name),
+   : QGLWidget(parent),
      eyeR(25), eyeTheta(1), eyePhi(M_PI*0.25),
      boxSize(1,1,1),
      fixedAxses(0),
@@ -176,7 +183,7 @@ RotationGLWidget::RotationGLWidget(
    }
    else
    {
-      kdDebug() << "parameter error" << endl;
+      kDebug() << "parameter error";
       boxSize = vec3<double>(1, 1, 1);
    }
 }
@@ -185,7 +192,7 @@ RotationGLWidget::RotationGLWidget(
 
 void RotationGLWidget::initializeGL(void)
 {
-   qglClearColor(QColor(black)); // set color to clear the background
+   qglClearColor(QColor(Qt::black)); // set color to clear the background
 
    glClearDepth(1);             // depth buffer setup
    glEnable(GL_DEPTH_TEST);     // depth testing
@@ -199,7 +206,7 @@ void RotationGLWidget::initializeGL(void)
    // set up the light
    glEnable(GL_LIGHTING);
    glEnable(GL_LIGHT0);
-   // set positon of light0
+   // set position of light0
    GLfloat lightPos[4]=
       {lightR * sin(lightTheta) * sin(lightPhi),
        lightR * sin(lightTheta) * cos(lightPhi),
@@ -221,17 +228,17 @@ void RotationGLWidget::initializeGL(void)
    glLoadIdentity();
 
    // z-axis, blue
-   qglColor(QColor(blue));
+   qglColor(QColor(Qt::blue));
    myGlArrow(fixedAxsesLength, 0.5f, 0.03f, 0.1f);
 
    // x-axis, red
-   qglColor(QColor(red));
+   qglColor(QColor(Qt::red));
    glRotatef(90, 0, 1, 0);
 
    myGlArrow(fixedAxsesLength, 0.5f, 0.03f, 0.1f);
 
    // y-axis, green
-   qglColor(QColor(green));
+   qglColor(QColor(Qt::green));
    glLoadIdentity();
    glRotatef(-90, 1, 0, 0);
    myGlArrow(fixedAxsesLength, 0.5f, 0.03f, 0.1f);
@@ -247,18 +254,18 @@ void RotationGLWidget::initializeGL(void)
    glNewList(bodyAxses, GL_COMPILE);
 
    // z-axis, blue
-   qglColor(QColor(blue));
+   qglColor(QColor(Qt::blue));
    myGlArrow(bodyAxsesLength, 0.5f, 0.03f, 0.1f);
 
    // x-axis, red
-   qglColor(QColor(red));
+   qglColor(QColor(Qt::red));
    glPushMatrix();
    glRotatef(90, 0, 1, 0);
    myGlArrow(bodyAxsesLength, 0.5f, 0.03f, 0.1f);
    glPopMatrix();
 
    // y-axis, green
-   qglColor(QColor(green));
+   qglColor(QColor(Qt::green));
    glPushMatrix();
    glRotatef(-90, 1, 0, 0);
    myGlArrow(bodyAxsesLength, 0.5f, 0.03f, 0.1f);
@@ -340,7 +347,7 @@ void RotationGLWidget::paintGL(void)
       180./M_PI * vec3<double>::angle(vec3<double>(0,0,1), omega);
    glPushMatrix();
    glRotatef(rotdeg, rotvec[0], rotvec[1], rotvec[2]);
-   qglColor(QColor(white));
+   qglColor(QColor(Qt::white));
    myGlArrow(7, .5f, .1f, 0.2f);
    glPopMatrix();
 
@@ -374,7 +381,7 @@ void RotationGLWidget::paintGL(void)
    // paint box
    glBegin(GL_QUADS);
    // front (z)
-   qglColor(QColor(blue));
+   qglColor(QColor(Qt::blue));
    glNormal3f( 0,0,1);
    glVertex3f( 1,  1,  1);
    glVertex3f(-1,  1,  1);
@@ -387,7 +394,7 @@ void RotationGLWidget::paintGL(void)
    glVertex3f(-1, -1, -1);
    glVertex3f( 1, -1, -1);
    // top (y)
-   qglColor(QColor(green));
+   qglColor(QColor(Qt::green));
    glNormal3f( 0,1,0);
    glVertex3f( 1,  1,  1);
    glVertex3f( 1,  1, -1);
@@ -401,7 +408,7 @@ void RotationGLWidget::paintGL(void)
    glVertex3f(-1, -1, -1);
    glVertex3f(-1, -1,  1);
    // left (-x)
-   qglColor(QColor(red));
+   qglColor(QColor(Qt::red));
    glNormal3f( -1,0,0);
    glVertex3f(-1,  1,  1);
    glVertex3f(-1,  1, -1);
@@ -482,15 +489,14 @@ KRotationSaver::KRotationSaver(WId id)
    readSettings();              // read global settings
    initData();                  // init e1,e2,e3,omega,solver
 
-   setEraseColor(black);
-   erase();                     // erase area
+   setEraseColor(Qt::black);
    glArea = new RotationGLWidget(
-      this, 0, omega, e1, e2, e3, J); // create gl widget
+      this, omega, e1, e2, e3, J); // create gl widget
    embed(glArea);               // embed gl widget and resize it
    glArea->show();              // show gl widget
 
    timer = new QTimer(this);
-   timer->start(deltaT, TRUE);
+   timer->start(deltaT, true);
    connect(timer, SIGNAL(timeout()), this, SLOT(doTimeStep()));
 }
 
@@ -558,21 +564,20 @@ void KRotationSaver::initData()
 void KRotationSaver::readSettings()
 {
    // read configuration settings from config file
-   KConfig *config = KGlobal::config();
-   config->setGroup("Settings");
+   KConfigGroup config(KGlobal::config(), "Settings");
 
    // internal saver parameters are set to stored values or left at their
    // default values if stored values are out of range
-   setTraceFlag(0, config->readBoolEntry("x trace", traceFlagDefault[0]));
-   setTraceFlag(1, config->readBoolEntry("y trace", traceFlagDefault[1]));
-   setTraceFlag(2, config->readBoolEntry("z trace", traceFlagDefault[2]));
-   setRandomTraces(config->readBoolEntry("random traces", randomTracesDefault));
+   setTraceFlag(0, config.readEntry("x trace", traceFlagDefault[0]));
+   setTraceFlag(1, config.readEntry("y trace", traceFlagDefault[1]));
+   setTraceFlag(2, config.readEntry("z trace", traceFlagDefault[2]));
+   setRandomTraces(config.readEntry("random traces", randomTracesDefault));
    setTraceLengthSeconds(
-      config->readDoubleNumEntry("length", traceLengthSecondsDefault));
+      config.readEntry("length", traceLengthSecondsDefault));
    setLz(
-      config->readDoubleNumEntry("Lz",     LzDefault));
+      config.readEntry("Lz",     LzDefault));
    setInitEulerTheta(
-      config->readDoubleNumEntry("theta",  initEulerThetaDefault));
+      config.readEntry("theta",  initEulerThetaDefault));
 }
 
 void KRotationSaver::setTraceLengthSeconds(const double& t)
@@ -590,6 +595,8 @@ const double KRotationSaver::traceLengthSecondsDefault = 3.0;
 
 const bool KRotationSaver::traceFlagDefault[3] = {false, false, true};
 
+const bool KRotationSaver::randomTracesDefault = true;
+
 void KRotationSaver::setLz(const double& Lz)
 {
    if (Lz >= LzLimitLower && Lz <= LzLimitUpper)
@@ -673,7 +680,7 @@ void KRotationSaver::doTimeStep()
    }
 
    glArea->updateGL();
-   timer->start(deltaT, TRUE); // restart timer
+   timer->start(deltaT, true); // restart timer
 }
 
 // public slot of KRotationSaver, forward resize event to public slot of glArea
@@ -687,14 +694,14 @@ void KRotationSaver::resizeGlArea(QResizeEvent* e)
 // KRotationSetup: dialog to setup screen saver parameters
 //-----------------------------------------------------------------------------
 
-KRotationSetup::KRotationSetup(QWidget* parent, const char* name)
-   : KRotationSetupUi(parent, name),
+KRotationSetup::KRotationSetup(QWidget* parent)
+   : KRotationSetupUi(parent),
      // create ssaver and give it the WinID of the preview area
      saver(new KRotationSaver(preview->winId()))
 {
    // the dialog should block, no other control center input should be possible
    // until the dialog is closed
-   setModal(TRUE);
+   setModal(true);
 
    lengthEdit->setValidator(
       new QDoubleValidator(
@@ -713,24 +720,23 @@ KRotationSetup::KRotationSetup(QWidget* parent, const char* name)
          3, thetaEdit));
 
    // set tool tips of editable fields
-   QToolTip::add(
-      lengthEdit,
-      i18n("Length of traces in seconds of visibility.\nValid values from %1 to %2.")
-      .arg(KRotationSaver::traceLengthSecondsLimitLower, 0, 'f', 2)
-      .arg(KRotationSaver::traceLengthSecondsLimitUpper, 0, 'f', 2));
-   QToolTip::add(
-      LzEdit,
-      i18n("Angular momentum in z direction in arbitrary units.\nValid values from %1 to %2.")
-      .arg(KRotationSaver::LzLimitLower, 0, 'f', 2)
-      .arg(KRotationSaver::LzLimitUpper, 0, 'f', 2));
-   QToolTip::add(
-      thetaEdit,
-      i18n("Gravitational constant in arbitrary units.\nValid values from %1 to %2.")
-      .arg(KRotationSaver::initEulerThetaLimitLower, 0, 'f', 2)
-      .arg(KRotationSaver::initEulerThetaLimitUpper, 0, 'f', 2));
+   lengthEdit->setToolTip(ki18n("Length of traces in seconds of visibility.\nValid values from %1 to %2.")
+      .subs(KRotationSaver::traceLengthSecondsLimitLower, 0, 'f', 2)
+      .subs(KRotationSaver::traceLengthSecondsLimitUpper, 0, 'f', 2)
+      .toString());
+   LzEdit->setToolTip(
+      ki18n("Angular momentum in z direction in arbitrary units.\nValid values from %1 to %2.")
+      .subs(KRotationSaver::LzLimitLower, 0, 'f', 2)
+      .subs(KRotationSaver::LzLimitUpper, 0, 'f', 2)
+      .toString());
+   thetaEdit->setToolTip(
+      ki18n("Gravitational constant in arbitrary units.\nValid values from %1 to %2.")
+      .subs(KRotationSaver::initEulerThetaLimitLower, 0, 'f', 2)
+      .subs(KRotationSaver::initEulerThetaLimitUpper, 0, 'f', 2)
+      .toString());
 
    // init preview area
-   preview->setBackgroundColor(black);
+   preview->setBackgroundColor(Qt::black);
    preview->show();    // otherwise saver does not get correct size
 
    // read settings from saver and update GUI elements with these values, saver
@@ -754,6 +760,16 @@ KRotationSetup::KRotationSetup(QWidget* parent, const char* name)
    // preview area.
    connect(preview, SIGNAL(resized(QResizeEvent*)),
            saver,   SLOT(resizeGlArea(QResizeEvent*)));
+   connect( OkButton,SIGNAL( clicked() ), this, SLOT( okButtonClickedSlot() ) );
+   connect( AboutButton, SIGNAL( clicked( ) ),this,SLOT( aboutButtonClickedSlot() ) );
+   connect( xTrace, SIGNAL( toggled( bool ) ), this, SLOT( xTraceToggled( bool ) ) );
+   connect( randTraces, SIGNAL( toggled( bool ) ), this, SLOT( randomTracesToggled( bool ) ) );
+   connect( yTrace, SIGNAL( toggled( bool ) ), this, SLOT( yTraceToggled( bool ) ) );
+   connect( zTrace, SIGNAL( toggled( bool ) ), this, SLOT( zTraceToggled( bool ) ) );
+   connect( lengthEdit, SIGNAL(textChanged(QString) ),this,SLOT( lengthEnteredSlot(QString) ) );
+   connect( LzEdit, SIGNAL(textChanged(QString ) ),this,SLOT( LzEnteredSlot( QString ) ) );
+   connect( thetaEdit, SIGNAL( textChanged( QString ) ), this, SLOT( thetaEnteredSlot( QString ) ) );
+
 }
 
 KRotationSetup::~KRotationSetup()
@@ -764,16 +780,15 @@ KRotationSetup::~KRotationSetup()
 // Ok pressed - save settings and exit
 void KRotationSetup::okButtonClickedSlot(void)
 {
-   KConfig* config = KGlobal::config();
-   config->setGroup("Settings");
-   config->writeEntry("x trace",       saver->traceFlag(0));
-   config->writeEntry("y trace",       saver->traceFlag(1));
-   config->writeEntry("z trace",       saver->traceFlag(2));
-   config->writeEntry("random traces", saver->randomTraces());
-   config->writeEntry("length",        saver->traceLengthSeconds());
-   config->writeEntry("Lz",            saver->Lz());
-   config->writeEntry("theta",         saver->initEulerTheta());
-   config->sync();
+   KConfigGroup config(KGlobal::config(), "Settings");
+   config.writeEntry("x trace",       saver->traceFlag(0));
+   config.writeEntry("y trace",       saver->traceFlag(1));
+   config.writeEntry("z trace",       saver->traceFlag(2));
+   config.writeEntry("random traces", saver->randomTraces());
+   config.writeEntry("length",        saver->traceLengthSeconds());
+   config.writeEntry("Lz",            saver->Lz());
+   config.writeEntry("theta",         saver->initEulerTheta());
+   config.sync();
    accept();
 }
 
@@ -816,10 +831,10 @@ void KRotationSetup::lengthEnteredSlot(const QString& s)
 void KRotationSetup::LzEnteredSlot(const QString& s)
 {
    saver->setLz(s.toDouble());
-   if (saver!=0) saver->initData();
+   saver->initData();
 }
 void KRotationSetup::thetaEnteredSlot(const QString& s)
 {
    saver->setInitEulerTheta(s.toDouble());
-   if (saver!=0) saver->initData();
+   saver->initData();
 }
