@@ -2,14 +2,13 @@
 //
 // KRotation screen saver for KDE
 // Copyright (C) 2004 Georg Drenkhahn
-// $Id: rotation.h 543449 2006-05-22 04:17:51Z howells $
+// $Id: rotation.h 787229 2008-03-18 20:26:20Z winterz $
 //
 //============================================================================
 
-#ifndef __ROTATION_H__
-#define __ROTATION_H__
+#ifndef ROTATION_H
+#define ROTATION_H
 
-#include <math.h>
 // STL headers
 #include <valarray>
 // Qt headers
@@ -26,7 +25,7 @@
 #include "rkodesolver.h"
 
 // KRotationSetupUi
-#include "rotationcfg.h"
+#include "ui_rotationcfg.h"
 
 //--------------------------------------------------------------------
 
@@ -86,14 +85,13 @@ class RotationGLWidget : public QGLWidget
   public:
    /** @brief Constructor of KRotation's GL widget
     * @param parent parent widget, passed to QGLWidget's constructor
-    * @param name name of widget, passed to QGLWidget's constructor
     * @param omega current rotation vector
     * @param e1 x trace data
     * @param e2 y trace data
     * @param e3 z trace data
     * @param J 3 vector with momenta of inertia with respect to the 3 figure
     * axes. */
-   RotationGLWidget(QWidget* parent, const char* name,
+   RotationGLWidget(QWidget* parent,
                     const vec3<double>& omega,
                     const std::deque<vec3<double> >& e1,
                     const std::deque<vec3<double> >& e2,
@@ -106,7 +104,7 @@ class RotationGLWidget : public QGLWidget
    /** Called if gl widget was resized.  Method makes adjustments for new
     * perspective */
    virtual void resizeGL(int w, int h);
-   /** Setup the GL enviroment */
+   /** Setup the GL environment */
    virtual void initializeGL();
 
   private:
@@ -216,7 +214,7 @@ class KRotationSaver : public KScreenSaver
    /** (Un)Sets the random trace flag. */
    inline void setRandomTraces(const bool& flag) {m_randomTraces = flag;}
    /** Default value for KRotationSaver::m_randomTraces */
-   static const bool randomTracesDefault = true;
+   static const bool randomTracesDefault;
 
    /** Returns the angular momentum. */
    inline double Lz(void) const {return m_Lz;}
@@ -293,6 +291,14 @@ class KRotationSaver : public KScreenSaver
 
 //--------------------------------------------------------------------
 
+class KRotationSetupUi : public QDialog, public Ui::KRotationSetupUi
+{
+public:
+  KRotationSetupUi( QWidget *parent ) : QDialog( parent ) {
+    setupUi( this );
+  }
+};
+
 /** @brief KRotation screen saver setup dialog.
  *
  * This class handles the KRotation screen saver setup dialog. */
@@ -301,7 +307,7 @@ class KRotationSetup : public KRotationSetupUi
    Q_OBJECT
 
   public:
-   KRotationSetup(QWidget* parent = NULL, const char* name = NULL);
+   KRotationSetup(QWidget* parent = NULL);
    ~KRotationSetup();
 
   public slots:
